@@ -4,6 +4,7 @@
   Copyright 2005-2006 Aaron Isotton <aaron@isotton.com>
   Copyright 2006      Paul Martin <pm@debian.org>
   Copyright 2012      Cyril Brulebois <kibi@debian.org>
+  Copyright 2020      daltomi <daltomi@disroot.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -48,10 +49,13 @@ extern int optind, opterr, optopt;
 namespace {
 
 // Globals
+static const char* optstring = "hV";
+
 struct option longopts[] =
 {
-    { "help",		no_argument,	NULL, 'h' },
-    { "version",	no_argument,	NULL, 'V' }
+    { "help",       no_argument,    NULL, 'h' },
+    { "version",    no_argument,    NULL, 'V' },
+    {  NULL,        0,              NULL,  0  }
 };
 
 volatile bool quit = false;
@@ -117,7 +121,7 @@ int main(int argc, char **argv) {
 	opterr = 0;
 	bool getopt_done = false;
 	while (!getopt_done) {
-	    int ch = getopt_long(argc, argv, "", longopts, NULL);
+	    int ch = getopt_long(argc, argv, optstring, longopts, NULL);
 	    switch (ch) {
 		case 'h':
 		    usage(std::cout);
