@@ -1,3 +1,24 @@
+/*
+  Color Bandwidth Meter (CBM) - display in real time the network traffic speed
+
+  Copyright 2005-2006 Aaron Isotton <aaron@isotton.com>
+  Copyright 2006      Paul Martin <pm@debian.org>
+
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License
+  as published by the Free Software Foundation; version 2
+  of the License.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "Window.hpp"
 #include "CursesError.hpp"
 #include <curses.h>
@@ -14,7 +35,7 @@ Window::~Window() {
 }
 	
 void Window::setPosition(unsigned x, unsigned y) {
-    mvwin((WINDOW*) win_, y, x);
+    mvderwin((WINDOW*) win_, y, x);
 }
 
 void Window::setSize(unsigned width, unsigned height) {
